<?php
// This file is part of
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

require_once("../../../../config.php");
require_once("$CFG->dirroot/mod/gradeimporter/lib.php");

require_once('submissiontype_form.php');
$cmid = required_param('cmid', PARAM_INT); // Course Module ID
$id   = required_param('id', PARAM_INT);  // Gradeimporter id
$typeid = optional_param('tid', -1, PARAM_INT); // Type id, used if editing already existing type

// Check if its inside a course and this gradeimporter exists
$cm = get_coursemodule_from_id('gradeimporter', $cmid, 0, false, MUST_EXIST);
$course = $DB->get_record('course', array('id' => $cm->course), '*', MUST_EXIST);
$gradeimporter = $DB->get_record('gradeimporter', array('id' => $cm->instance), '*', MUST_EXIST);

// Get context
$context = context_module::instance($cm->id);

// Sets url
$url = new moodle_url('/mod/gradeimporter/submissiontype.php', array('cmid' => $cm->id));
if (!empty($id)) {
    $url->param('id', $id);
}
$PAGE->set_url($url);

// Requires user to be logged in and have edit capability
require_login($course, false, $cm);
require_capability('mod/gradeimporter:edit', $context);

if (!isSet($entry)) {
    $entry = new stdClass();
    $entry->id = null;
}

$entry->cmid = $cm->id;
$entry->gradeimporterid = $gradeimporter->id;

$mform = new mod_gradeimporter_submissiontype_form(null, array('submissiontype' => $entry));

if ($mform->is_cancelled()) {
    if ($id) {
        redirect("view.php?id=$cm->id&mode=entry&hook=$id");
    } else {
        redirect("view.php?id=$cm->id");
    }
} else if ($entry = $mform->get_data()) {
    // If data is valid
    // Submit $entry into DB
    if (empty($entry->id)) {
        // If entry doesn't have id its a new entry
        $entry->gradeimporterid = $gradeimporter->id;
        $isnewentry = true;
    } else {
        $isnewentry = false;
    }

    $entry->description        = $entry->description_editor["text"];
    $entry->descriptionformat  = FORMAT_HTML;

    if ($isnewentry) {
        $entry->id = $DB->insert_record('gradeimporter_submissiontype', $entry);
    } else {
        $DB->update_record('gradeimporter', $submissiontype);
    }

    if ($isnewentry) {
        // Update completion state
        $completion = new completion_info($course);
        if ($completion->is_enabled($cm) == COMPLETION_TRACKING_AUTOMATIC && $gradeimporter->completionentries) {
            $completion->update_state($cm, COMPLETION_COMPLETE);
        }
    }

    redirect("../submission/submission.php?id=$id&cmid=$cm->id&page=0");
}

if ($typeid != -1) {
    // If typeid is not empty then its editing an already existing submissiontype
    // Get data from DB and insert into form
    $PAGE->navbar->add(get_string('edit'));
    $data = $DB->get_record('gradeimporter_submissiontype', array('id' => $typeid));
    $data->description_editor = array('text' => $data->description,
                                        'format' => $data->descriptionformat
                                    );
    $mform->set_data($data);
}

$PAGE->set_title($gradeimporter->name);
$PAGE->set_heading($course->fullname);
echo $OUTPUT->header();
echo $OUTPUT->heading(format_string($gradeimporter->name), 2);
if ($gradeimporter->intro) {
    echo $OUTPUT->box(format_module_intro('gradeimporter', $gradeimporter, $cm->id), 'generalbox', 'intro');
}

$mform->display();

echo $OUTPUT->footer();
